get_multiple_metadata: Import the metadata from many mapstat files

Description Usage Arguments Value

View source: R/mapstat_metadata.R

Description

Import the metadata from many mapstat files

Usage

1
get_multiple_metadata(input, type = "directory", ...)

Arguments

input

Either the name of a directory containing the files to be imported, or a character vector containing file paths.

type

Specify whether the input is of type "directory" (default) or "vector".

...

Additional arguments to be passed to get_single_metadata. At the moment, the only such argument is shorten_sample_id.

Value

A data frame containing the metadata of the provided mapstat files. A quick summary of each column is printed to the console.


roeder/mapstatHelpers documentation built on Nov. 5, 2019, 3:14 a.m.