read_multiple_mapstats: Import multiple mapstat files

Description Usage Arguments Value

View source: R/mapstat_import.R

Description

Import multiple mapstat files

Usage

1
read_multiple_mapstats(input, type = "directory", ...)

Arguments

input

Either the name of a directory containing the files to be imported, or a character vector containing file paths.

type

Specify whether the input is of type "directory" (default) or "vector".

...

Additional arguments to be passed to read_single_mapstat, auch as shorten_sample_id and engine.

Value

A data frame containing information from all imported mapstat files. The (by default shortened) filenames are added in a column called sample_id.


roeder/mapstatHelpers documentation built on Nov. 5, 2019, 3:14 a.m.