read_refdata: Import a refdata file

Description Usage Arguments Value

View source: R/refdata_import.R

Description

Import a refdata file

Usage

1
read_refdata(path, engine = "readr")

Arguments

path

Path to refdata file

engine

Which function should be used to read in the files?

The default, "readr", uses the read_delim() function from the readr package. You can also choose "fread", which will use fread() from the data.table package.

"readr" is a bit slower, but throws more useful warnings. You can cut the reading time by about 30 to 40 percent with "fread".

Value

A data frame containing the refdata information.


roeder/mapstatHelpers documentation built on Nov. 5, 2019, 3:14 a.m.