Description Usage Arguments Value
View source: R/mapstat_metadata.R
Import the metadata from many mapstat files
1 | get_multiple_metadata(input, type = "directory", ...)
|
input |
Either the name of a directory containing the files to be imported, or a character vector containing file paths. |
type |
Specify whether the |
... |
Additional arguments to be passed to |
A data frame containing the metadata of the provided mapstat files. A quick summary of each column is printed to the console.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.