Description Usage Arguments Value
View source: R/mapstat_import.R
Import multiple mapstat files
1 | read_multiple_mapstats(input, type = "directory", ...)
|
input |
Either the name of a directory containing the files to be imported, or a character vector containing file paths. |
type |
Specify whether the |
... |
Additional arguments to be passed to |
A data frame containing information from all imported mapstat files.
The (by default shortened) filenames are added in a column called sample_id.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.