Description Usage Arguments Value
View source: R/mapstat_import.R
Import a mapstat file
1 | read_single_mapstat(path, shorten_sample_id = TRUE, engine = "readr")
|
path |
Path to file |
shorten_sample_id |
Should the If |
engine |
Which function should be used to read in the files? The default,
|
A data frame containing information from the imported mapstat file.
The (by default shortened) filename is added in a column called sample_id.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.